==> lxqt-panel_0.14.1.orig.tar.xz: lxqt-panel-0.14.1/plugin-kbindicator/translations/kbindicator_ca.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="ca">
<context>
    <name>Content</name>
    <message>
        <location filename="../src/content.cpp" line="43"/>
        <source>C</source>
        <comment>Label for CapsLock indicator</comment>
        <translation>M</translation>
    </message>
    <message>
        <location filename="../src/content.cpp" line="46"/>
        <source>CapsLock</source>
        <comment>Tooltip for CapsLock indicator</comment>
        <translation>Bloq Maj</translation>
    </message>
    <message>
        <location filename="../src/content.cpp" line="50"/>
        <source>N</source>
        <comment>Label for NumLock indicator</comment>
        <translation>N</translation>
    </message>
    <message>
        <location filename="../src/content.cpp" line="52"/>
        <source>NumLock</source>
        <comment>Tooltip for NumLock indicator</comment>
        <translation>Bloq Núm</translation>
    </message>
    <message>
        <location filename="../src/content.cpp" line="57"/>
        <source>S</source>
        <comment>Label for ScrollLock indicator</comment>
        <translation>D</translation>
    </message>
    <message>
        <location filename="../src/content.cpp" line="59"/>
        <source>ScrollLock</source>
        <comment>Tooltip for ScrollLock indicator</comment>
        <translation>Bloq Despl</translation>
    </message>
    <message>
        <location filename="../src/content.cpp" line="90"/>
        <source>Layout</source>
        <translation>Disposició</translation>
    </message>
    <message>
        <location filename="../src/content.cpp" line="90"/>
        <source>Variant</source>
        <translation>Variant</translation>
    </message>
</context>
<context>
    <name>KbdStateConfig</name>
    <message>
        <location filename="../src/kbdstateconfig.ui" line="14"/>
        <source>Keyboard state settings</source>
        <translation>Ajusts de l&apos;estat del teclat</translation>
    </message>
    <message>
        <location filename="../src/kbdstateconfig.ui" line="20"/>
        <source>Lock Indicators</source>
        <translation>Indicadors de bloqueig</translation>
    </message>
    <message>
        <location filename="../src/kbdstateconfig.ui" line="26"/>
        <source>Show Caps Lock</source>
        <translation>Mostra el bloqueig de majúscules</translation>
    </message>
    <message>
        <location filename="../src/kbdstateconfig.ui" line="33"/>
        <source>Show Num Lock</source>
        <translation>Mostra el bloqueig de teclat numèric</translation>
    </message>
    <message>
        <location filename="../src/kbdstateconfig.ui" line="40"/>
        <source>Show Scroll Lock</source>
        <translation>Mostra el bloqueig de desplaçament</translation>
    </message>
    <message>
        <location filename="../src/kbdstateconfig.ui" line="50"/>
        <source>Keyboard Layout Indicator</source>
        <translation>Indicador de la disposició de teclat</translation>
    </message>
    <message>
        <location filename="../src/kbdstateconfig.ui" line="62"/>
        <source>Switching policy</source>
        <translation>Política d&apos;intercanvi</translation>
    </message>
    <message>
        <location filename="../src/kbdstateconfig.ui" line="102"/>
        <source>Configure layouts</source>
        <translation>Configura les disposicions</translation>
    </message>
    <message>
        <location filename="../src/kbdstateconfig.ui" line="69"/>
        <source>Global</source>
        <translation>Global</translation>
    </message>
    <message>
        <location filename="../src/kbdstateconfig.ui" line="79"/>
        <source>Window</source>
        <translation>Finestra</translation>
    </message>
    <message>
        <location filename="../src/kbdstateconfig.ui" line="89"/>
        <source>Application</source>
        <translation>Aplicació</translation>
    </message>
</context>
</TS>

==> lxqt-panel_0.16.1.orig.tar.xz: lxqt-panel-0.16.1/plugin-kbindicator/translations/kbindicator_ca.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="ca">
<context>
    <name>Content</name>
    <message>
        <location filename="../src/content.cpp" line="46"/>
        <source>C</source>
        <comment>Label for CapsLock indicator</comment>
        <translation>M</translation>
    </message>
    <message>
        <location filename="../src/content.cpp" line="49"/>
        <source>CapsLock</source>
        <comment>Tooltip for CapsLock indicator</comment>
        <translation>Bloq Maj</translation>
    </message>
    <message>
        <location filename="../src/content.cpp" line="53"/>
        <source>N</source>
        <comment>Label for NumLock indicator</comment>
        <translation>N</translation>
    </message>
    <message>
        <location filename="../src/content.cpp" line="55"/>
        <source>NumLock</source>
        <comment>Tooltip for NumLock indicator</comment>
        <translation>Bloq Núm</translation>
    </message>
    <message>
        <location filename="../src/content.cpp" line="60"/>
        <source>S</source>
        <comment>Label for ScrollLock indicator</comment>
        <translation>D</translation>
    </message>
    <message>
        <location filename="../src/content.cpp" line="62"/>
        <source>ScrollLock</source>
        <comment>Tooltip for ScrollLock indicator</comment>
        <translation>Bloq Despl</translation>
    </message>
    <message>
        <location filename="../src/content.cpp" line="105"/>
        <source>Layout</source>
        <translation>Disposició</translation>
    </message>
    <message>
        <location filename="../src/content.cpp" line="105"/>
        <source>Variant</source>
        <translation>Variant</translation>
    </message>
</context>
<context>
    <name>KbdStateConfig</name>
    <message>
        <location filename="../src/kbdstateconfig.ui" line="14"/>
        <source>Keyboard state settings</source>
        <translation>Ajusts de l&apos;estat del teclat</translation>
    </message>
    <message>
        <location filename="../src/kbdstateconfig.ui" line="20"/>
        <source>Lock Indicators</source>
        <translation>Indicadors de bloqueig</translation>
    </message>
    <message>
        <location filename="../src/kbdstateconfig.ui" line="26"/>
        <source>Show Caps Lock</source>
        <translation>Mostra el bloqueig de majúscules</translation>
    </message>
    <message>
        <location filename="../src/kbdstateconfig.ui" line="33"/>
        <source>Show Num Lock</source>
        <translation>Mostra el bloqueig de teclat numèric</translation>
    </message>
    <message>
        <location filename="../src/kbdstateconfig.ui" line="40"/>
        <source>Show Scroll Lock</source>
        <translation>Mostra el bloqueig de desplaçament</translation>
    </message>
    <message>
        <location filename="../src/kbdstateconfig.ui" line="50"/>
        <source>Keyboard Layout Indicator</source>
        <translation>Indicador de la disposició de teclat</translation>
    </message>
    <message>
        <location filename="../src/kbdstateconfig.ui" line="62"/>
        <source>Switching policy</source>
        <translation>Política d&apos;intercanvi</translation>
    </message>
    <message>
        <location filename="../src/kbdstateconfig.ui" line="99"/>
        <source>Flags path pattern:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/kbdstateconfig.ui" line="106"/>
        <source>File path pattern for country flags. Must contain &lt;strong&gt;%1&lt;/strong&gt; which is replaced by the two letter ISO country code (lower case).&lt;br&gt;&lt;br&gt;Example: /usr/share/iso-flags-svg/country-squared/%1.svg</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/kbdstateconfig.ui" line="116"/>
        <source>Configure layouts</source>
        <translation>Configura les disposicions</translation>
    </message>
    <message>
        <location filename="../src/kbdstateconfig.ui" line="69"/>
        <source>Global</source>
        <translation>Global</translation>
    </message>
    <message>
        <location filename="../src/kbdstateconfig.ui" line="79"/>
        <source>Window</source>
        <translation>Finestra</translation>
    </message>
    <message>
        <location filename="../src/kbdstateconfig.ui" line="89"/>
        <source>Application</source>
        <translation>Aplicació</translation>
    </message>
</context>
</TS>
